abacusai.chat_message — AbacusAI documentation

# `abacusai.chat_message`

## Module Contents

### Classes

`ChatMessage` | A single chat message with Abacus Chat.

class abacusai.chat_message.ChatMessage(client, role=None, text=None, timestamp=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A single chat message with Abacus Chat.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - role (str) – The role of the message sender

    - text (list) – A list of text segments for the message

    - timestamp (str) – The timestamp at which the message was sent

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict